@@ -23,14 +23,17 @@ class InsightServiceClient(AbstractClient):
         super(InsightServiceClient, self).__init__(tenant, username, password, env)
 
         self.tenant_type = 'SMARTFARM_PLUS'
-        if env == EnvType.PROD:
+
+        if env.value == EnvType.PROD.value:
             self.base_url = InsightServiceCfg.PROD_BASE_URL
-        elif env == EnvType.QA:
+        elif env.value == EnvType.QA.value:
             self.base_url = InsightServiceCfg.QA_BASE_URL
-        elif env == EnvType.DEV:
+        elif env.value == EnvType.DEV.value:
             self.base_url = InsightServiceCfg.DEV_BASE_URL
-        elif env == EnvType.PROD2:
+        elif env.value == EnvType.PROD2.value:
             self.base_url = InsightServiceCfg.PROD2_BASE_URL
+        else:
+            self.base_url = InsightServiceCfg.PROD_BASE_URL
 
         self.configuration = Configuration()
         # set base url
